import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl =
  'https://raw.githubusercontent.com/kusuma63663/ice-7/main/carsales.csv';

// Format the Data from the URI response
const parseRow = (d) => {
  d.Units = +d.Units;
  d.TotalAmount = +d.TotalAmount;
  d.HorsePower = +d.HorsePower;
  return d;
};

const margin = { top: 20, right: 20, bottom: 60, left: 60 };
const width =
  window.innerWidth - margin.left - margin.right;
const height =
  window.innerHeight - margin.top - margin.bottom;

// Appends a SVG in the body of HTML
const svg = select('body')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    'translate(' + margin.left + ',' + margin.top + ')',
  );

const main = async () => {
  // Creating a new Scatter Plot object
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.TotalAmount)
    .yValue((d) => d.HorsePower)
    .margin(margin)
    .radius(5);

  // Plotting the Scatter Plot axes based on the given parameters
  svg.call(plot);

  const columns = ['Units', 'TotalAmount', 'HorsePower'];

  // Adding X-axis Label
  svg
    .append('text')
    .attr('class', 'x label')
    .attr('text-anchor', 'end')
    .attr('x', width)
    .attr('y', height - 6)
    .text('Total Amount ($)');

  // Adding Y-axis Label
  svg
    .append('text')
    .attr('class', 'y label')
    .attr('text-anchor', 'end')
    .attr('y', -10)
    .attr('dy', '.75em')
    .attr('transform', 'rotate(-90)')
    .text('Horse Power');

  // Plotting the data on the Scatter Plot
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    svg
      .select('.x.label')
      .text(columns[i % columns.length]);
    i++;
  }, 2000);
};
main();
